@@ -17,7 +17,7 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 H2I_DESCRIPTION="[@]pkgdescription[@]"
-H2I="$(basename $0)"
+H2I=${0##*/}
 H2I_BUGREPORT="[@]pkgbugreport[@]"
 H2I_DATADIR="[@]pkgdatadir[@]"
 H2I_VERSION="[@]pkgversion[@]"
@@ -100,7 +100,6 @@ function h2i_parse_options
 	H2I_LAST_LINE=$(echo "$1" | tail -1)
        	if echo "$H2I_LAST_LINE" | grep -qi 'report'
 	then
-		H2I_BUGREPORT=$(echo "$H2I_LAST_LINE" | cut -d'<' -f2 | cut -d'>' -f1)
 		let H2I_END=$(echo "$1" | wc -l)-1
 	else
 		H2I_END=$(echo "$1" | wc -l)
@@ -129,7 +128,7 @@ fi
 # get program name
 if [[ -z $H2I_INFO_PROGRAM_NAME ]]
 then
-	H2I_INFO_PROGRAM_NAME="$1"
+	H2I_INFO_PROGRAM_NAME=${1##*/}
 fi
 
 # get examples
@@ -217,7 +216,7 @@ H2I_INFO_OPTIONS=$(h2i_options "$H2I_PROGRAM_OPTIONS")
 function h2i_bugreport()
 {
 	H2I_COMMENT=$(tail -n 1 <<< "$1")
-	if grep -qi "report bugs" <<<"$H2I_COMMENT"
+	if grep -qi "report bugs" <<< "$H2I_COMMENT"
 	then echo "$H2I_COMMENT" | cut -d'<' -f2 | cut -d'>' -f1| sed -re 's,(\w@),\1@,g'
 	else echo "Insert your mail address here"
 	fi
@@ -226,13 +225,13 @@ function h2i_bugreport()
 H2I_INFO_BUGREPORT=$(h2i_bugreport "$H2I_OUTPUT")
 
 # generate the texi file
-cat >"$1.texi" <<EOF
+cat > "${H2I_INFO_PROGRAM_NAME}.texi" <<EOF
 \input texinfo	@c -*-texinfo-*-
 @comment It was generated by help2info $H2I_VERSION.
 @comment %**start of header
-@setfilename $1.info
+@setfilename ${H2I_INFO_PROGRAM_NAME}.info
 @include version.texi
-@settitle $1 @value{VERSION}
+@settitle $H2I_INFO_PROGRAM_NAME @value{VERSION}
 @syncodeindex pg cp
 @comment %**end of header
 @copying
@@ -257,7 +256,7 @@ this Manual, like GNU software.''
 @end copying
 @dircategory $H2I_INFO_DIRCATEGORY
 @direntry
-* $H2I_INFO_PROGRAM_NAME: ($1). $H2I_INFO_DESCRIPTION
+* $H2I_INFO_PROGRAM_NAME: ($H2I_INFO_PROGRAM_NAME). $H2I_INFO_DESCRIPTION
 @end direntry
 
 @titlepage
@@ -279,7 +278,7 @@ this Manual, like GNU software.''
 
 @menu
 * Introduction:: Introduction.
-* Invoking $1::	Invocation.
+* Invoking $H2I_INFO_PROGRAM_NAME::	Invocation.
 * Examples:: Some samples of use.
 * Reporting Bugs:: Reporting bugs
 * Copying This Manual:: The license for this documentation.
@@ -291,15 +290,15 @@ this Manual, like GNU software.''
 @cindex introduction
 $H2I_INFO_DESCRIPTION
 
-@node Invoking $1
-@chapter Invoking $1
+@node Invoking $H2I_INFO_PROGRAM_NAME
+@chapter Invoking $H2I_INFO_PROGRAM_NAME
 @pindex invoking
-@cindex invoking @command{$1}
+@cindex invoking @command{$H2I_INFO_PROGRAM_NAME}
 @verbatim
 $H2I_INFO_USAGE
 @end verbatim
 
-@command{$1} may be invoked with the following command-line options:
+@command{$H2I_INFO_PROGRAM_NAME} may be invoked with the following command-line options:
 
 $H2I_INFO_OPTIONS
 
@@ -313,7 +312,7 @@ $H2I_INFO_EXAMPLES
 @chapter Reporting Bugs
 @pindex bugs
 @cindex reporting bugs
-Email bug reports to @email{$H2I_INFO_BUGREPORT}. Be sure to include the word @dfn{$1} somewhere in the @code{Subject:} field. Also, please include the output of @samp{$1 --version} in the body of your report if at all possible.
+Email bug reports to @email{$H2I_INFO_BUGREPORT}. Be sure to include the word @dfn{$H2I_INFO_PROGRAM_NAME} somewhere in the @code{Subject:} field. Also, please include the output of @samp{$H2I_INFO_PROGRAM_NAME --version} in the body of your report if at all possible.
 
 
 @node Copying This Manual
